@@ -4,12 +4,13 @@ package Pod::Weaver::PluginBundle::ZURBORG;
 
 # ABSTRACT: a bundle that add Bugs section to the Default bundle
 
-our $VERSION = '0.004';    # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use namespace::autoclean;
 
 use Pod::Weaver::Config::Assembler;
 
+
 sub mvp_bundle_config {
     return map {
         $_->[1] = Pod::Weaver::Config::Assembler->expand_package( $_->[1] );
@@ -75,7 +76,7 @@ Pod::Weaver::PluginBundle::ZURBORG - a bundle that add Bugs section to the Defau
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 METHODS
 
@@ -86,7 +87,7 @@ Config method for Pod::Weaver
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/zurborg/libdist-zilla-pluginbundle-zurborg-perl/issues
+L<https://github.com/zurborg/libdist-zilla-pluginbundle-zurborg-perl/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
